==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/awscdk/CdkConfigCommonOptions.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Common options for `cdk.json`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.566Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.CdkConfigCommonOptions")
@software.amazon.jsii.Jsii.Proxy(CdkConfigCommonOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface CdkConfigCommonOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) A command to execute before synthesis.
     * <p>
     * This command will be called when
     * running <code>cdk synth</code> or when <code>cdk watch</code> identifies a change in your source
     * code before redeployment.
     * <p>
     * Default: - no build command
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getBuildCommand() {
        return null;
    }

    /**
     * (experimental) cdk.out directory.
     * <p>
     * Default: "cdk.out"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getCdkout() {
        return null;
    }

    /**
     * (experimental) Additional context to include in `cdk.json`.
     * <p>
     * Default: - no additional context
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.String> getContext() {
        return null;
    }

    /**
     * (experimental) Include all feature flags in cdk.json.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getFeatureFlags() {
        return null;
    }

    /**
     * (experimental) To protect you against unintended changes that affect your security posture, the AWS CDK Toolkit prompts you to approve security-related changes before deploying them.
     * <p>
     * Default: ApprovalLevel.BROADENING
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.awscdk.ApprovalLevel getRequireApproval() {
        return null;
    }

    /**
     * (experimental) Glob patterns to exclude from `cdk watch`.
     * <p>
     * Default: []
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getWatchExcludes() {
        return null;
    }

    /**
     * (experimental) Glob patterns to include in `cdk watch`.
     * <p>
     * Default: []
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getWatchIncludes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CdkConfigCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CdkConfigCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<CdkConfigCommonOptions> {
        java.lang.String buildCommand;
        java.lang.String cdkout;
        java.util.Map<java.lang.String, java.lang.String> context;
        java.lang.Boolean featureFlags;
        io.github.cdklabs.projen.awscdk.ApprovalLevel requireApproval;
        java.util.List<java.lang.String> watchExcludes;
        java.util.List<java.lang.String> watchIncludes;

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getBuildCommand}
         * @param buildCommand A command to execute before synthesis.
         *                     This command will be called when
         *                     running <code>cdk synth</code> or when <code>cdk watch</code> identifies a change in your source
         *                     code before redeployment.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder buildCommand(java.lang.String buildCommand) {
            this.buildCommand = buildCommand;
            return this;
        }

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getCdkout}
         * @param cdkout cdk.out directory.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cdkout(java.lang.String cdkout) {
            this.cdkout = cdkout;
            return this;
        }

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getContext}
         * @param context Additional context to include in `cdk.json`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder context(java.util.Map<java.lang.String, java.lang.String> context) {
            this.context = context;
            return this;
        }

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getFeatureFlags}
         * @param featureFlags Include all feature flags in cdk.json.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder featureFlags(java.lang.Boolean featureFlags) {
            this.featureFlags = featureFlags;
            return this;
        }

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getRequireApproval}
         * @param requireApproval To protect you against unintended changes that affect your security posture, the AWS CDK Toolkit prompts you to approve security-related changes before deploying them.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder requireApproval(io.github.cdklabs.projen.awscdk.ApprovalLevel requireApproval) {
            this.requireApproval = requireApproval;
            return this;
        }

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getWatchExcludes}
         * @param watchExcludes Glob patterns to exclude from `cdk watch`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder watchExcludes(java.util.List<java.lang.String> watchExcludes) {
            this.watchExcludes = watchExcludes;
            return this;
        }

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getWatchIncludes}
         * @param watchIncludes Glob patterns to include in `cdk watch`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder watchIncludes(java.util.List<java.lang.String> watchIncludes) {
            this.watchIncludes = watchIncludes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CdkConfigCommonOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public CdkConfigCommonOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CdkConfigCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CdkConfigCommonOptions {
        private final java.lang.String buildCommand;
        private final java.lang.String cdkout;
        private final java.util.Map<java.lang.String, java.lang.String> context;
        private final java.lang.Boolean featureFlags;
        private final io.github.cdklabs.projen.awscdk.ApprovalLevel requireApproval;
        private final java.util.List<java.lang.String> watchExcludes;
        private final java.util.List<java.lang.String> watchIncludes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.buildCommand = software.amazon.jsii.Kernel.get(this, "buildCommand", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.cdkout = software.amazon.jsii.Kernel.get(this, "cdkout", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.context = software.amazon.jsii.Kernel.get(this, "context", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.featureFlags = software.amazon.jsii.Kernel.get(this, "featureFlags", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.requireApproval = software.amazon.jsii.Kernel.get(this, "requireApproval", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.awscdk.ApprovalLevel.class));
            this.watchExcludes = software.amazon.jsii.Kernel.get(this, "watchExcludes", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.watchIncludes = software.amazon.jsii.Kernel.get(this, "watchIncludes", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.buildCommand = builder.buildCommand;
            this.cdkout = builder.cdkout;
            this.context = builder.context;
            this.featureFlags = builder.featureFlags;
            this.requireApproval = builder.requireApproval;
            this.watchExcludes = builder.watchExcludes;
            this.watchIncludes = builder.watchIncludes;
        }

        @Override
        public final java.lang.String getBuildCommand() {
            return this.buildCommand;
        }

        @Override
        public final java.lang.String getCdkout() {
            return this.cdkout;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getContext() {
            return this.context;
        }

        @Override
        public final java.lang.Boolean getFeatureFlags() {
            return this.featureFlags;
        }

        @Override
        public final io.github.cdklabs.projen.awscdk.ApprovalLevel getRequireApproval() {
            return this.requireApproval;
        }

        @Override
        public final java.util.List<java.lang.String> getWatchExcludes() {
            return this.watchExcludes;
        }

        @Override
        public final java.util.List<java.lang.String> getWatchIncludes() {
            return this.watchIncludes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getBuildCommand() != null) {
                data.set("buildCommand", om.valueToTree(this.getBuildCommand()));
            }
            if (this.getCdkout() != null) {
                data.set("cdkout", om.valueToTree(this.getCdkout()));
            }
            if (this.getContext() != null) {
                data.set("context", om.valueToTree(this.getContext()));
            }
            if (this.getFeatureFlags() != null) {
                data.set("featureFlags", om.valueToTree(this.getFeatureFlags()));
            }
            if (this.getRequireApproval() != null) {
                data.set("requireApproval", om.valueToTree(this.getRequireApproval()));
            }
            if (this.getWatchExcludes() != null) {
                data.set("watchExcludes", om.valueToTree(this.getWatchExcludes()));
            }
            if (this.getWatchIncludes() != null) {
                data.set("watchIncludes", om.valueToTree(this.getWatchIncludes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.awscdk.CdkConfigCommonOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CdkConfigCommonOptions.Jsii$Proxy that = (CdkConfigCommonOptions.Jsii$Proxy) o;

            if (this.buildCommand != null ? !this.buildCommand.equals(that.buildCommand) : that.buildCommand != null) return false;
            if (this.cdkout != null ? !this.cdkout.equals(that.cdkout) : that.cdkout != null) return false;
            if (this.context != null ? !this.context.equals(that.context) : that.context != null) return false;
            if (this.featureFlags != null ? !this.featureFlags.equals(that.featureFlags) : that.featureFlags != null) return false;
            if (this.requireApproval != null ? !this.requireApproval.equals(that.requireApproval) : that.requireApproval != null) return false;
            if (this.watchExcludes != null ? !this.watchExcludes.equals(that.watchExcludes) : that.watchExcludes != null) return false;
            return this.watchIncludes != null ? this.watchIncludes.equals(that.watchIncludes) : that.watchIncludes == null;
        }

        @Override
        public final int hashCode() {
            int result = this.buildCommand != null ? this.buildCommand.hashCode() : 0;
            result = 31 * result + (this.cdkout != null ? this.cdkout.hashCode() : 0);
            result = 31 * result + (this.context != null ? this.context.hashCode() : 0);
            result = 31 * result + (this.featureFlags != null ? this.featureFlags.hashCode() : 0);
            result = 31 * result + (this.requireApproval != null ? this.requireApproval.hashCode() : 0);
            result = 31 * result + (this.watchExcludes != null ? this.watchExcludes.hashCode() : 0);
            result = 31 * result + (this.watchIncludes != null ? this.watchIncludes.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/awscdk/CdkConfigCommonOptions.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Common options for <code>cdk.json</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.260Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.CdkConfigCommonOptions")
@software.amazon.jsii.Jsii.Proxy(CdkConfigCommonOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface CdkConfigCommonOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) A command to execute before synthesis.
     * <p>
     * This command will be called when
     * running <code>cdk synth</code> or when <code>cdk watch</code> identifies a change in your source
     * code before redeployment.
     * <p>
     * Default: - no build command
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getBuildCommand() {
        return null;
    }

    /**
     * (experimental) cdk.out directory.
     * <p>
     * Default: "cdk.out"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getCdkout() {
        return null;
    }

    /**
     * (experimental) Additional context to include in <code>cdk.json</code>.
     * <p>
     * Default: - no additional context
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.Object> getContext() {
        return null;
    }

    /**
     * (experimental) Include all feature flags in cdk.json.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getFeatureFlags() {
        return null;
    }

    /**
     * (experimental) To protect you against unintended changes that affect your security posture, the AWS CDK Toolkit prompts you to approve security-related changes before deploying them.
     * <p>
     * Default: ApprovalLevel.BROADENING
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.awscdk.ApprovalLevel getRequireApproval() {
        return null;
    }

    /**
     * (experimental) Glob patterns to exclude from <code>cdk watch</code>.
     * <p>
     * Default: []
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getWatchExcludes() {
        return null;
    }

    /**
     * (experimental) Glob patterns to include in <code>cdk watch</code>.
     * <p>
     * Default: []
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getWatchIncludes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CdkConfigCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CdkConfigCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<CdkConfigCommonOptions> {
        java.lang.String buildCommand;
        java.lang.String cdkout;
        java.util.Map<java.lang.String, java.lang.Object> context;
        java.lang.Boolean featureFlags;
        io.github.cdklabs.projen.awscdk.ApprovalLevel requireApproval;
        java.util.List<java.lang.String> watchExcludes;
        java.util.List<java.lang.String> watchIncludes;

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getBuildCommand}
         * @param buildCommand A command to execute before synthesis.
         *                     This command will be called when
         *                     running <code>cdk synth</code> or when <code>cdk watch</code> identifies a change in your source
         *                     code before redeployment.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder buildCommand(java.lang.String buildCommand) {
            this.buildCommand = buildCommand;
            return this;
        }

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getCdkout}
         * @param cdkout cdk.out directory.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cdkout(java.lang.String cdkout) {
            this.cdkout = cdkout;
            return this;
        }

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getContext}
         * @param context Additional context to include in <code>cdk.json</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder context(java.util.Map<java.lang.String, ? extends java.lang.Object> context) {
            this.context = (java.util.Map<java.lang.String, java.lang.Object>)context;
            return this;
        }

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getFeatureFlags}
         * @param featureFlags Include all feature flags in cdk.json.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder featureFlags(java.lang.Boolean featureFlags) {
            this.featureFlags = featureFlags;
            return this;
        }

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getRequireApproval}
         * @param requireApproval To protect you against unintended changes that affect your security posture, the AWS CDK Toolkit prompts you to approve security-related changes before deploying them.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder requireApproval(io.github.cdklabs.projen.awscdk.ApprovalLevel requireApproval) {
            this.requireApproval = requireApproval;
            return this;
        }

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getWatchExcludes}
         * @param watchExcludes Glob patterns to exclude from <code>cdk watch</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder watchExcludes(java.util.List<java.lang.String> watchExcludes) {
            this.watchExcludes = watchExcludes;
            return this;
        }

        /**
         * Sets the value of {@link CdkConfigCommonOptions#getWatchIncludes}
         * @param watchIncludes Glob patterns to include in <code>cdk watch</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder watchIncludes(java.util.List<java.lang.String> watchIncludes) {
            this.watchIncludes = watchIncludes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CdkConfigCommonOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public CdkConfigCommonOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CdkConfigCommonOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CdkConfigCommonOptions {
        private final java.lang.String buildCommand;
        private final java.lang.String cdkout;
        private final java.util.Map<java.lang.String, java.lang.Object> context;
        private final java.lang.Boolean featureFlags;
        private final io.github.cdklabs.projen.awscdk.ApprovalLevel requireApproval;
        private final java.util.List<java.lang.String> watchExcludes;
        private final java.util.List<java.lang.String> watchIncludes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.buildCommand = software.amazon.jsii.Kernel.get(this, "buildCommand", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.cdkout = software.amazon.jsii.Kernel.get(this, "cdkout", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.context = software.amazon.jsii.Kernel.get(this, "context", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.featureFlags = software.amazon.jsii.Kernel.get(this, "featureFlags", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.requireApproval = software.amazon.jsii.Kernel.get(this, "requireApproval", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.awscdk.ApprovalLevel.class));
            this.watchExcludes = software.amazon.jsii.Kernel.get(this, "watchExcludes", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.watchIncludes = software.amazon.jsii.Kernel.get(this, "watchIncludes", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.buildCommand = builder.buildCommand;
            this.cdkout = builder.cdkout;
            this.context = (java.util.Map<java.lang.String, java.lang.Object>)builder.context;
            this.featureFlags = builder.featureFlags;
            this.requireApproval = builder.requireApproval;
            this.watchExcludes = builder.watchExcludes;
            this.watchIncludes = builder.watchIncludes;
        }

        @Override
        public final java.lang.String getBuildCommand() {
            return this.buildCommand;
        }

        @Override
        public final java.lang.String getCdkout() {
            return this.cdkout;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Object> getContext() {
            return this.context;
        }

        @Override
        public final java.lang.Boolean getFeatureFlags() {
            return this.featureFlags;
        }

        @Override
        public final io.github.cdklabs.projen.awscdk.ApprovalLevel getRequireApproval() {
            return this.requireApproval;
        }

        @Override
        public final java.util.List<java.lang.String> getWatchExcludes() {
            return this.watchExcludes;
        }

        @Override
        public final java.util.List<java.lang.String> getWatchIncludes() {
            return this.watchIncludes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getBuildCommand() != null) {
                data.set("buildCommand", om.valueToTree(this.getBuildCommand()));
            }
            if (this.getCdkout() != null) {
                data.set("cdkout", om.valueToTree(this.getCdkout()));
            }
            if (this.getContext() != null) {
                data.set("context", om.valueToTree(this.getContext()));
            }
            if (this.getFeatureFlags() != null) {
                data.set("featureFlags", om.valueToTree(this.getFeatureFlags()));
            }
            if (this.getRequireApproval() != null) {
                data.set("requireApproval", om.valueToTree(this.getRequireApproval()));
            }
            if (this.getWatchExcludes() != null) {
                data.set("watchExcludes", om.valueToTree(this.getWatchExcludes()));
            }
            if (this.getWatchIncludes() != null) {
                data.set("watchIncludes", om.valueToTree(this.getWatchIncludes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.awscdk.CdkConfigCommonOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CdkConfigCommonOptions.Jsii$Proxy that = (CdkConfigCommonOptions.Jsii$Proxy) o;

            if (this.buildCommand != null ? !this.buildCommand.equals(that.buildCommand) : that.buildCommand != null) return false;
            if (this.cdkout != null ? !this.cdkout.equals(that.cdkout) : that.cdkout != null) return false;
            if (this.context != null ? !this.context.equals(that.context) : that.context != null) return false;
            if (this.featureFlags != null ? !this.featureFlags.equals(that.featureFlags) : that.featureFlags != null) return false;
            if (this.requireApproval != null ? !this.requireApproval.equals(that.requireApproval) : that.requireApproval != null) return false;
            if (this.watchExcludes != null ? !this.watchExcludes.equals(that.watchExcludes) : that.watchExcludes != null) return false;
            return this.watchIncludes != null ? this.watchIncludes.equals(that.watchIncludes) : that.watchIncludes == null;
        }

        @Override
        public final int hashCode() {
            int result = this.buildCommand != null ? this.buildCommand.hashCode() : 0;
            result = 31 * result + (this.cdkout != null ? this.cdkout.hashCode() : 0);
            result = 31 * result + (this.context != null ? this.context.hashCode() : 0);
            result = 31 * result + (this.featureFlags != null ? this.featureFlags.hashCode() : 0);
            result = 31 * result + (this.requireApproval != null ? this.requireApproval.hashCode() : 0);
            result = 31 * result + (this.watchExcludes != null ? this.watchExcludes.hashCode() : 0);
            result = 31 * result + (this.watchIncludes != null ? this.watchIncludes.hashCode() : 0);
            return result;
        }
    }
}
